@@ -2,7 +2,7 @@ package HTTP::MobileAgent::Plugin::SmartPhone;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 sub HTTP::MobileAgent::is_smartphone {
     my $self = shift;
@@ -22,6 +22,10 @@ sub HTTP::MobileAgent::is_ipad {
     shift->user_agent =~ /\(iPad/;
 }
 
+sub HTTP::MobileAgent::is_ipod {
+    shift->user_agent =~ /\(iPod/;
+}
+
 sub HTTP::MobileAgent::is_android {
     shift->user_agent =~ /Android/;
 }
